// Data structures

#[derive(Clone)]
pub struct ObjectConstructor { }  // TODO
